algorithms: Choice of Algorithm and Hyper Parameters

algorithmsR Documentation

Choice of Algorithm and Hyper Parameters

Description

Choose between three algorithms for evaluating normal (and t-) distributions and define hyper parameters.

Usage

GenzBretz(maxpts = 25000, abseps = 0.001, releps = 0)
Miwa(steps = 128, checkCorr = TRUE, maxval = 1e3)
TVPACK(abseps = 1e-6)

Arguments

maxpts

maximum number of function values as integer. The internal FORTRAN code always uses a minimum number depending on the dimension. (for example 752 for three-dimensional problems).

abseps

absolute error tolerance; for TVPACK only used for dimension 3.

releps

relative error tolerance as double.

steps

number of grid points to be evaluated; cannot be larger than 4097.

checkCorr

logical indicating if a check for singularity of the correlation matrix should be performed (once per function call to pmvt() or pmvnorm()).

maxval

replacement for Inf when non-orthant probabilities involving Inf shall be computed.

Details

There are three algorithms available for evaluating normal (and two algorithms for t-) probabilities: The default is the randomized Quasi-Monte-Carlo procedure by \bibcitetmvtnorm::numerical-:1992,mvtnorm::comparison:1993 and \bibcitetmvtnorm::Genz_Bretz_2002 applicable to arbitrary covariance structures and dimensions up to 1000.

For normal probabilities, smaller dimensions (up to 20) and non-singular covariance matrices, the algorithm by \bibcitetmvtnorm::Miwa+Hayter+Kuriki:2003 can be used as well. This algorithm can compute orthant probabilities (lower being -Inf or upper equal to Inf). Non-orthant probabilities are computed from the corresponding orthant probabilities, however, infinite limits are replaced by maxval along with a warning.

For two- and three-dimensional problems and semi-infinite integration region, TVPACK implements an interface to the methods described by \bibcitetmvtnorm::Genz:2004.

Value

An object of class "GenzBretz", "Miwa", or "TVPACK" defining hyper parameters.

References

\bibshow

*


mvtnorm documentation built on May 21, 2026, 3:01 p.m.