Computes the equicoordinate quantile function of the multivariate normal
distribution for arbitrary correlation matrices
based on inversion of pmvnorm.
qmvnorm(p, interval = NULL, tail = c("lower.tail", "upper.tail", "both.tails"), mean = 0, corr = NULL, sigma = NULL, algorithm = GenzBretz(), ptol = 0.001, maxiter = 500, trace = FALSE, ...)lower.tail gives the quantile $x$ for which
$P[X \le x] = p$, upper.tail gives $x$ with
$P[X > x] = p$ and
both.tails leads to $x$
with $P[-x \le X \le x] = p$.corr or
sigma can be specified. If sigma is given, the
problem is standardized. If neither corr nor
sigma is given, the identity matrix is used
for sigma. maxiter is the
maximum number of iterations for the root finding algorithm. trace
prints the iterations of the root finder.GenzBretz.quantile and f.quantile
give the location of the quantile and the difference between the distribution
function evaluated at the quantile and p.
Only equicoordinate quantiles are computed, i.e., the quantiles in each dimension coincide. The result is seed dependend.
pmvnorm, qmvtqmvnorm(0.95, sigma = diag(2), tail = "both")
Run the code above in your browser using DataLab